@@ -1,5 +1,3 @@
-from __future__ import absolute_import
-
 import atexit
 import codecs
 import glob
@@ -9,6 +7,8 @@ import platform
 import stat
 import subprocess
 import warnings
+from configparser import MissingSectionHeaderError, RawConfigParser
+from io import StringIO
 from tempfile import gettempdir
 from threading import Lock
 from uuid import uuid4
@@ -17,13 +17,12 @@ import numpy as np
 import scipy.sparse as sp
 from sklearn.base import BaseEstimator
 from sklearn.exceptions import NotFittedError
-from sklearn.externals import six
 from sklearn.utils.extmath import softmax
 from sklearn.utils.multiclass import check_classification_targets
 from sklearn.utils.validation import check_array, check_consistent_length, check_X_y, column_or_1d
 
 
-FLOATS = (float, np.float, np.float16, np.float32, np.float64, np.double)
+FLOATS = (float, np.float16, np.float32, np.float64, np.double)
 INTS = (numbers.Integral, np.integer)
 NOT_FITTED_ERROR_DESC = "Estimator not fitted, call `fit` before exploiting the model."
 NOT_IMPLEMENTED_ERROR_DESC = "This method isn't implemented in base class."
@@ -65,50 +64,38 @@ class Config(object):
     RGF_AVAILABLE = None
     FASTRGF_AVAILABLE = None
 
-    def __init__(self):
+    def __init__(self, verbose=False):
         (self.DEFAULT_RGF_PATH, self.RGF_PATH,
          self.DEFAULT_FASTRGF_PATH, self.FASTRGF_PATH, self.TEMP_PATH) = self.init_paths()
         (self.RGF_PATH, self.RGF_AVAILABLE,
-         self.FASTRGF_PATH, self.FASTRGF_AVAILABLE) = self.set_paths_and_availability()
+         self.FASTRGF_PATH, self.FASTRGF_AVAILABLE) = self.set_paths_and_availability(verbose)
 
     @classmethod
     def init_paths(cls):
         if cls.TEMP_PATH is None:
-            config = six.moves.configparser.RawConfigParser()
+            config = RawConfigParser()
             path = os.path.join(os.path.expanduser('~'), '.rgfrc')
 
             try:
                 with codecs.open(path, 'r', 'utf-8') as cfg:
-                    with six.StringIO(cfg.read()) as strIO:
-                        config.readfp(strIO)
-            except six.moves.configparser.MissingSectionHeaderError:
+                    with StringIO(cfg.read()) as strIO:
+                        config.read_file(strIO)
+            except MissingSectionHeaderError:
                 with codecs.open(path, 'r', 'utf-8') as cfg:
-                    with six.StringIO('[glob]\n' + cfg.read()) as strIO:
-                        config.readfp(strIO)
+                    with StringIO('[glob]\n' + cfg.read()) as strIO:
+                        config.read_file(strIO)
             except Exception:
                 pass
 
             if SYSTEM in ('Windows', 'Microsoft'):
                 try:
-                    if config.has_option(config.sections()[0], 'exe_location'):
-                        warnings.warn("Config flag 'exe_location' has been deprecated "
-                                      "and will be removed in the future release.\n"
-                                      "Please use 'rgf_location' flag instead.")
-                        cls.RGF_PATH = os.path.abspath(config.get(config.sections()[0], 'exe_location'))
-                    else:
-                        cls.RGF_PATH = os.path.abspath(config.get(config.sections()[0], 'rgf_location'))
+                    cls.RGF_PATH = os.path.abspath(config.get(config.sections()[0], 'rgf_location'))
                 except Exception:
                     cls.RGF_PATH = os.path.join(os.path.expanduser('~'), 'rgf.exe')
                 cls.DEFAULT_RGF_PATH = 'rgf.exe'
             else:  # Linux, Darwin (macOS), etc.
                 try:
-                    if config.has_option(config.sections()[0], 'exe_location'):
-                        warnings.warn("Config flag 'exe_location' has been deprecated "
-                                      "and will be removed in the future release.\n"
-                                      "Please use 'rgf_location' flag instead.")
-                        cls.RGF_PATH = os.path.abspath(config.get(config.sections()[0], 'exe_location'))
-                    else:
-                        cls.RGF_PATH = os.path.abspath(config.get(config.sections()[0], 'rgf_location'))
+                    cls.RGF_PATH = os.path.abspath(config.get(config.sections()[0], 'rgf_location'))
                 except Exception:
                     cls.RGF_PATH = os.path.join(os.path.expanduser('~'), 'rgf')
                 cls.DEFAULT_RGF_PATH = 'rgf'
@@ -164,7 +151,9 @@ class Config(object):
         return True
 
     @classmethod
-    def is_fastrgf_executable(cls, path):
+    def is_fastrgf_executable(cls, path, verbose=False):
+        if verbose:
+            print("[FastRGF] Investigate {}".format(path))
         temp_x_loc = os.path.join(cls.TEMP_PATH, 'temp_fastrgf.train.data.x')
         temp_y_loc = os.path.join(cls.TEMP_PATH, 'temp_fastrgf.train.data.y')
         temp_model_loc = os.path.join(cls.TEMP_PATH, "temp_fastrgf.model")
@@ -198,12 +187,18 @@ class Config(object):
         try:
             subprocess.check_output(cmd_train, stderr=subprocess.STDOUT)
             subprocess.check_output(cmd_pred, stderr=subprocess.STDOUT)
-        except Exception:
+        except Exception as e:
+            if verbose:
+                print(e)
             return False
+
+        if verbose:
+            print("[FastRGF] Found in {}".format(path))
+
         return True
 
     @classmethod
-    def set_paths_and_availability(cls):
+    def set_paths_and_availability(cls, verbose=False):
         if cls.RGF_AVAILABLE is None or cls.FASTRGF_AVAILABLE is None:
             cls.RGF_AVAILABLE = True
             if cls.is_rgf_executable(os.path.join(cls.CURRENT_DIR, cls.DEFAULT_RGF_PATH)):
@@ -218,11 +213,11 @@ class Config(object):
                               "RGF estimators will be unavailable for usage.")
 
             cls.FASTRGF_AVAILABLE = True
-            if cls.is_fastrgf_executable(cls.CURRENT_DIR):
+            if cls.is_fastrgf_executable(cls.CURRENT_DIR, verbose):
                 cls.FASTRGF_PATH = cls.CURRENT_DIR
-            elif cls.is_fastrgf_executable(cls.DEFAULT_FASTRGF_PATH):
+            elif cls.is_fastrgf_executable(cls.DEFAULT_FASTRGF_PATH, verbose):
                 cls.FASTRGF_PATH = cls.DEFAULT_FASTRGF_PATH
-            elif cls.is_fastrgf_executable(cls.FASTRGF_PATH):
+            elif cls.is_fastrgf_executable(cls.FASTRGF_PATH, verbose):
                 pass
             else:
                 cls.FASTRGF_AVAILABLE = False
@@ -248,7 +243,6 @@ COUNTER = AtomicCounter()
 
 
 def sparse_savetxt(filename, input_array, including_header=True):
-    zip_func = six.moves.zip
     if sp.isspmatrix_csr(input_array):
         input_array = input_array.tocoo()
     else:
@@ -259,7 +253,7 @@ def sparse_savetxt(filename, input_array, including_header=True):
     with open(filename, 'w') as fw:
         if including_header:
             fw.write('sparse {0:d}\n'.format(input_array.shape[-1]))
-        for i, j, v in zip_func(input_array.row, input_array.col, input_array.data):
+        for i, j, v in zip(input_array.row, input_array.col, input_array.data):
             if i == current_sample_row:
                 line.append('{0}:{1}'.format(j, v))
             else:
@@ -494,6 +488,11 @@ class CommonRGFEstimatorBase(BaseEstimator):
 
 
 class RGFClassifierMixin(object):
+    def _more_tags(self):
+        return {'X_types': ['2darray', 'sparse', '1dlabels'],
+                'requires_y' : True,
+                '_xfail_checks': {'check_sample_weights_invariance': 'sample_weight must have positive values'}}
+
     @property
     def classes_(self):
         """The classes labels when `fit` is performed."""
@@ -563,6 +562,7 @@ class RGFClassifierMixin(object):
             raise ValueError("Classifier can't predict when only one class is present.")
 
         self._fitted = True
+        self.n_features_in_ = self._n_features
 
         return self
 
@@ -629,6 +629,11 @@ class RGFClassifierMixin(object):
 
 
 class RGFRegressorMixin(object):
+    def _more_tags(self):
+        return {'X_types': ['2darray', 'sparse', '1dlabels'],
+                'requires_y' : True,
+                '_xfail_checks': {'check_sample_weights_invariance': 'sample_weight must have positive values'}}
+
     def fit(self, X, y, sample_weight=None):
         """
         Build a regressor from the training set (X, y).
@@ -667,6 +672,7 @@ class RGFRegressorMixin(object):
         self._fit_regression_task(X, y, sample_weight, params)
 
         self._fitted = True
+        self.n_features_in_ = self._n_features
 
         return self
 
